% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/getBreakpoints.R
\name{refineBreakpoints}
\alias{refineBreakpoints}
\title{Refine breakpoints}
\usage{
refineBreakpoints(model, fragments, breakpoints = model$breakpoints,
  confint = 0.99)
}
\arguments{
\item{model}{An \code{\link{aneuBiHMM}} object or a file that contains such an object.}

\item{fragments}{A \code{\link{GRanges-class}} object with read fragments or a file that contains such an object.}

\item{breakpoints}{A \code{\link{GRanges-class}} object with breakpoints and confidence intervals, as returned by function \code{\link{getBreakpoints}}.}

\item{confint}{Desired confidence interval for breakpoints.}
}
\value{
An \code{\link{aneuBiHMM}} with adjusted breakpoint coordinates and confidence interals, bins and segments.
}
\description{
Refine breakpoints with confidence intervals from an initial estimate (from \code{\link{getBreakpoints}}).
}
\details{
Breakpoints are refined by shifting the breakpoint within its initial confidence interval read by read and maximizing the probability of observing the left-right read distribution.
}
\examples{
## Get an example BED file with single-cell-sequencing reads
bedfile <- system.file("extdata", "KK150311_VI_07.bam.bed.gz", package="AneuFinderData")
## Bin the data into bin size 1Mp
readfragments <- binReads(bedfile, assembly='mm10', binsize=1e6,
                  chromosomes=c(1:19,'X','Y'), reads.return=TRUE)
binned <- binReads(bedfile, assembly='mm10', binsize=1e6,
                  chromosomes=c(1:19,'X','Y'))
## Fit the Hidden Markov Model
model <- findCNVs.strandseq(binned[[1]])
## Add confidence intervals
breakpoints <- getBreakpoints(model, readfragments)
## Refine breakpoints
refined.model <- refineBreakpoints(model, readfragments, breakpoints)

}
